pub enum Role {
User,
Assistant,
Tool,
}Expand description
Role of a message participant in a completion request.
Variants
User
A message from the end user or calling code.
Assistant
A message from the assistant (used for multi-turn conversations).
Tool
A tool result message.
Anthropic: sent as role: "user" with type: "tool_result" content.
OpenAI: sent as role: "tool" with tool_call_id.